@@ -1,71 +1,3 @@
-##' proposalvariance_nospat function
-##'
-##' A function to compute an approximate scaling matrix for use with MCMC algorithms. Works for models with baseline hazard derived from the
-##' exponential survival model and assumes no frailties i.e. this is used for a non-spatial survival analysis.
-##'
-##' @param X matrix of covariates 
-##' @param delta censoring indicator, a vector 
-##' @param tm observed event times, a vector
-##' @param betahat an estimate of beta 
-##' @param omegahat an estimate of omega
-##' @param betapriorsd standard deviation of the prior for beta 
-##' @param omegapriorsd standard deviation of the prior for omega
-##' @return ...
-##' @export
-
-proposalvariance_exponential_nospat <- function(X,delta,tm,betahat,omegahat,betapriorsd,omegapriorsd){
-    N <- nrow(X)
-    d <- ncol(X)
-    sigma <- matrix(NA,d+1,d+1)
-    Xbetahat <- X%*%betahat
-    expXbetahat <- exp(Xbetahat)
-    
-    for(k in 1:d){
-        for(l in 1:d){
-            sigma[k,l] <- sum(-X[,k]*X[,l]*expXbetahat*exp(omegahat)*tm) - as.numeric(k==l)/betapriorsd^2
-        }
-        sigma[k,d+1] <- sigma[d+1,k] <- sum(-X[,k]*expXbetahat*exp(omegahat)*tm) 
-    }
-    sigma[d+1,d+1] <- -sum(expXbetahat*exp(omegahat)*tm) - 1/omegapriorsd^2
-    
-    return(solve(-sigma))      
-}
-
-
-
-
-##' derivlogindepGaussianprior function
-##'
-##' A function to compute the first and second derivatives of the log-density assuming independent Gaussian priors for each of the parameters.
-##'
-##' @param beta a vector, the parameter beta
-##' @param omega a vector, the parameter omega
-##' @param eta a vector, the parameter eta 
-##' @param priors an object of class 'mcmcPrior', see ?mcmcPrior
-##' @return ...
-##' @export
-
-derivlogindepGaussianprior <- function(beta=NULL,omega=NULL,eta=NULL,priors){
-    deriv1 <- c((-1/priors$betaprior$sd^2)*(beta-priors$betaprior$mean),(-1/priors$omegaprior$sd^2)*(omega-priors$omegaprior$mean),(-1/priors$etaprior$sd^2)*(eta-priors$etaprior$mean))
-    sdbeta <- priors$betaprior$sd
-    sdomega <- priors$omegaprior$sd
-    sdeta <- priors$etaprior$sd
-    if (length(priors$betaprior$sd)<length(beta)){
-        sdbeta <- rep(priors$betaprior$sd,length(beta))
-    }
-    if (length(priors$omegaprior$sd)<length(omega)){
-        sdomega <- rep(priors$omegaprior$sd,length(omega))
-    }
-    if (length(priors$etaprior$sd)<length(eta)){
-        sdeta <- rep(priors$etaprior$sd,length(eta))
-    }
-    deriv2 <- c(-1/sdbeta^2,-1/sdomega^2,-1/sdeta^2)
-    return(list(deriv1=deriv1,deriv2=deriv2))
-}
-
-
-
-
 ##' QuadApprox function
 ##'
 ##' A function to compute the second derivative of a function (of several real variables) using a quadratic approximation  on a 
@@ -80,7 +12,7 @@ derivlogindepGaussianprior <- function(beta=NULL,omega=NULL,eta=NULL,priors){
 ##' @export
 
 
-QuadApprox <- function(fun,npts,argRanges,plot=TRUE,...){
+QuadApprox <- function(fun,npts,argRanges,plot=FALSE,...){
 
     npar <- length(argRanges)
     vals <- lapply(argRanges,function(x){seq(x[1],x[2],length.out=npts)})
@@ -166,10 +98,12 @@ QuadApprox <- function(fun,npts,argRanges,plot=TRUE,...){
 
 ##' fixmatrix function
 ##'
-##' A function to 
+##' !! THIS FUNCTION IS NOT INTENDED FOR GENERAL USE !!
 ##'
-##' @param mat X 
-##' @return ...
+##' A function to fix up an estimated covariance matrix using a VERY ad-hoc method.
+##'
+##' @param mat a matrix
+##' @return the fixed matrix
 ##' @export
 
 fixmatrix <- function(mat){
@@ -261,18 +195,18 @@ fixmatrix <- function(mat){
 
 ##' proposalVariance function
 ##'
-##' A function to 
+##' A function to compute an approximate scaling matrix for the MCMC algorithm. Not intended for general use. 
 ##'
-##' @param X X 
-##' @param surv X 
-##' @param betahat X 
-##' @param omegahat X 
-##' @param Yhat X 
-##' @param priors X 
-##' @param cov.model X 
-##' @param u X 
-##' @param control X 
-##' @return ...
+##' @param X the design matrix, containing covariate information 
+##' @param surv an object of class Surv 
+##' @param betahat an estimate of beta 
+##' @param omegahat an estimate of omega 
+##' @param Yhat an estimate of Y 
+##' @param priors the priors 
+##' @param cov.model the spatial covariance model 
+##' @param u a vector of pairwise distances 
+##' @param control a list containg various control parameters for the MCMC and post-processing routines 
+##' @return an estimate of eta and also an approximate scaling matrix for the MCMC
 ##' @export
 
 proposalVariance <- function(X,surv,betahat,omegahat,Yhat,priors,cov.model,u,control){
@@ -289,10 +223,11 @@ proposalVariance <- function(X,surv,betahat,omegahat,Yhat,priors,cov.model,u,con
     # eta
     logpost <- function(eta,surv,X,beta,omega,Y,priors,cov.model,u,control){
 
-        sigma <- matrix(EvalCov(cov.model=cov.model,u=u,parameters=eta),n,n)
+        etapars <- cov.model$itrans(eta)
+        sigma <- matrix(EvalCov(cov.model=cov.model,u=u,parameters=etapars),n,n)
         cholsigma <- t(chol(sigma))
         cholsigmainv <- solve(cholsigma)
-        MU <- -cov.model$itrans[[control$sigmaidx]](eta[control$sigmaidx])^2/2
+        MU <- -etapars[control$sigmaidx]^2/2
         gamma <- cholsigmainv%*%(Y-MU)  
         
         logpost <- logPosterior(surv=surv,X=X,beta=beta,omega=omega,eta=eta,gamma=gamma,priors=priors,cov.model=cov.model,u=u,control=control)        
@@ -305,7 +240,7 @@ proposalVariance <- function(X,surv,betahat,omegahat,Yhat,priors,cov.model,u,con
         npts <- 10
     }
     rgs <- getparranges(priors=priors,leneta=leneta)   
-    qa <- QuadApprox(logpost,npts=npts,argRanges=rgs,surv=surv,X=X,beta=betahat,omega=omegahat,Y=Yhat,priors=priors,cov.model=cov.model,u=u,control=control)
+    qa <- QuadApprox(logpost,npts=npts,argRanges=rgs,plot=control$plotcal,surv=surv,X=X,beta=betahat,omega=omegahat,Y=Yhat,priors=priors,cov.model=cov.model,u=u,control=control)
     
     matr <- qa$curvature
     etahat <- qa$max
@@ -313,10 +248,11 @@ proposalVariance <- function(X,surv,betahat,omegahat,Yhat,priors,cov.model,u,con
     # entry for eta in propossal covariance
     sigma[(lenbeta+lenomega+1):(lenbeta+lenomega+leneta),(lenbeta+lenomega+1):(lenbeta+lenomega+leneta)] <- matr    
         
-    #estimate of gamma  
-    ssigma <- matrix(EvalCov(cov.model=cov.model,u=u,parameters=etahat),n,n)
+    #estimate of gamma
+    etahatpars <- cov.model$itrans(etahat)  
+    ssigma <- matrix(EvalCov(cov.model=cov.model,u=u,parameters=etahatpars),n,n)
     cholssigma <- t(chol(ssigma))
-    MU <- -cov.model$itrans[[control$sigmaidx]](etahat[control$sigmaidx])^2/2
+    MU <- -etahatpars[control$sigmaidx]^2/2
     gammahat <- solve(cholssigma)%*%(Yhat-MU)
     
     hessian <- logPosterior(surv=surv,X=X,beta=betahat,omega=omegahat,eta=etahat,gamma=gammahat,priors=priors,cov.model=cov.model,u=u,control=control,hessian=TRUE)
@@ -337,18 +273,18 @@ proposalVariance <- function(X,surv,betahat,omegahat,Yhat,priors,cov.model,u,con
 
 ##' proposalVariance_gridded function
 ##'
-##' A function to 
+##' A function to compute an approximate scaling matrix for the MCMC algorithm. Not intended for general use. 
 ##'
-##' @param X X 
-##' @param surv X 
-##' @param betahat X 
-##' @param omegahat X 
-##' @param Yhat X 
-##' @param priors X 
-##' @param cov.model X 
-##' @param u X 
-##' @param control X 
-##' @return ...
+##' @param X the design matrix, containing covariate information 
+##' @param surv an object of class Surv 
+##' @param betahat an estimate of beta 
+##' @param omegahat an estimate of omega 
+##' @param Yhat an estimate of Y 
+##' @param priors the priors 
+##' @param cov.model the spatial covariance model 
+##' @param u a vector of pairwise distances 
+##' @param control a list containg various control parameters for the MCMC and post-processing routines 
+##' @return an estimate of eta and also an approximate scaling matrix for the MCMC
 ##' @export
 
 proposalVariance_gridded <- function(X,surv,betahat,omegahat,Yhat,priors,cov.model,u,control){
@@ -365,12 +301,12 @@ proposalVariance_gridded <- function(X,surv,betahat,omegahat,Yhat,priors,cov.mod
     # eta
     logpost <- function(eta,surv,X,beta,omega,Ygrid,priors,cov.model,u,control){
         
-        covbase <- matrix(EvalCov(cov.model=cov.model,u=u,parameters=eta),control$Mext,control$Next)
+        etapars <- cov.model$itrans(eta)
+        covbase <- matrix(EvalCov(cov.model=cov.model,u=u,parameters=etapars),control$Mext,control$Next)
         
         rootQeigs <- sqrt(1/Re(fft(covbase)))   
        
-        pars <- sapply(1:length(eta),function(i){cov.model$itrans[[i]](eta[i])})
-        ymean <- -pars[which(cov.model$parnames=="sigma")]^2/2
+        ymean <- -etapars[control$sigmaidx]^2/2
         gamma <- GammafromY(Ygrid,rootQeigs=rootQeigs,mu=ymean)  
         
         logpost <- logPosterior_gridded(surv=surv,X=X,beta=beta,omega=omega,eta=eta,gamma=gamma,priors=priors,cov.model=cov.model,u=u,control=control)        
@@ -383,7 +319,7 @@ proposalVariance_gridded <- function(X,surv,betahat,omegahat,Yhat,priors,cov.mod
         npts <- 10
     }
     rgs <- getparranges(priors=priors,leneta=leneta)   
-    qa <- QuadApprox(logpost,npts=npts,argRanges=rgs,surv=surv,X=X,beta=betahat,omega=omegahat,Ygrid=Ygrid,priors=priors,cov.model=cov.model,u=u,control=control)
+    qa <- QuadApprox(logpost,npts=npts,argRanges=rgs,plot=control$plotcal,surv=surv,X=X,beta=betahat,omega=omegahat,Ygrid=Ygrid,priors=priors,cov.model=cov.model,u=u,control=control)
     
     matr <- qa$curvature
     etahat <- qa$max
@@ -393,11 +329,11 @@ proposalVariance_gridded <- function(X,surv,betahat,omegahat,Yhat,priors,cov.mod
     # entry for eta in propossal covariance
     sigma[(lenbeta+lenomega+1):(lenbeta+lenomega+leneta),(lenbeta+lenomega+1):(lenbeta+lenomega+leneta)] <- matr    
         
-    #estimate of gamma  
-    covbase <- matrix(EvalCov(cov.model=cov.model,u=u,parameters=etahat),control$Mext,control$Next)        
+    #estimate of gamma
+    etahatpars <- cov.model$itrans(etahat)  
+    covbase <- matrix(EvalCov(cov.model=cov.model,u=u,parameters=etahatpars),control$Mext,control$Next)        
     rootQeigs <- sqrt(1/Re(fft(covbase)))   
-    pars <- sapply(1:length(etahat),function(i){cov.model$itrans[[i]](etahat[i])})
-    ymean <- -pars[which(cov.model$parnames=="sigma")]^2/2
+    ymean <- -etahatpars[control$sigmaidx]^2/2
     gammahat <- GammafromY(Ygrid,rootQeigs=rootQeigs,mu=ymean)
     
     hessian <- logPosterior_gridded(surv=surv,X=X,beta=betahat,omega=omegahat,eta=etahat,gamma=gammahat,priors=priors,cov.model=cov.model,u=u,control=control,hessian=TRUE)
@@ -426,25 +362,44 @@ proposalVariance_gridded <- function(X,surv,betahat,omegahat,Yhat,priors,cov.mod
 
 ##' estimateY function
 ##'
-##' A function to 
+##' A function to get an initial estimate of Y, to be used in calibrating the MCMC. Not for general use
 ##'
-##' @param X X 
-##' @param betahat X 
-##' @param omegahat X 
-##' @param surv X
-##' @param control X 
-##' @return ...
+##' @param X the design matrix containing covariate information 
+##' @param betahat an estimate of beta 
+##' @param omegahat an estimate of omega 
+##' @param surv an object of class Surv
+##' @param control a list containg various control parameters for the MCMC and post-processing routines 
+##' @return an estimate of Y, to be used in calibrating the MCMC
 ##' @export
 
 estimateY <- function(X,betahat,omegahat,surv,control){
-
-    censoringtype <- attr(surv,"type")
    
     omega <- control$omegaitrans(omegahat) # this is omega on the correct scale
     
-    haz <- setupHazard(dist=control$dist,pars=omega,grad=FALSE,hess=FALSE)
+    haz <- setupHazard(dist=control$dist,pars=omega,grad=FALSE,hess=FALSE)    
+    
+    tsubs <- guess_t(surv)   
+    
+    Y <- -X%*%betahat - log(haz$H(tsubs)) # greedy estimate of Y (maximise individual contributions to log-likelihood) ... note log(delta) is now omitted  
 
-    n <- nrow(X)
+    return(Y)    
+}
+
+
+
+##' guess_t function
+##'
+##' A function to get an initial guess of the failure time t, to be used in calibrating the MCMC. Not for general use
+##'
+##' @param surv an object of class Surv 
+##' @return a guess at the failure times
+##' @export
+
+guess_t <- function(surv){
+
+    n <- nrow(surv)
+    
+    censoringtype <- attr(surv,"type")
     
     if(censoringtype=="left" | censoringtype=="right"){
         notcensored <- surv[,"status"]==1
@@ -452,7 +407,7 @@ estimateY <- function(X,betahat,omegahat,surv,control){
     else{
         rightcensored <- surv[,"status"] == 0
         notcensored <- surv[,"status"] == 1
-        lefttruncated <- surv[,"status"] == 2
+        leftcensored <- surv[,"status"] == 2
         intervalcensored <- surv[,"status"] == 3
     }   
 
@@ -482,7 +437,7 @@ estimateY <- function(X,betahat,omegahat,surv,control){
             if(rightcensored[i]){
                 tpot <- tsubs[notcensored][tsubs[notcensored]>tsubs[i]] # potential t
             }
-            if(lefttruncated[i]){
+            if(leftcensored[i]){
                 tpot <- tsubs[notcensored][tsubs[notcensored]<tsubs[i]] # potential t
             }
             if(intervalcensored[i]){
@@ -499,9 +454,6 @@ estimateY <- function(X,betahat,omegahat,surv,control){
 
     }
     
-    
-    
-    Y <- -X%*%betahat - log(haz$H(tsubs)) # greedy estimate of Y (maximise individual contributions to log-likelihood) ... note log(delta) is now omitted  
+    return(tsubs)
 
-    return(Y)    
 }
\ No newline at end of file
